@@ -51,6 +51,8 @@ namespace Beagle {
 
 	public class Indexable : Versioned, IComparable {
 
+		static private bool Debug = false;
+
 		// This is the type of indexing operation represented by
 		// this Indexable object.  We default to Add, for historical
 		// reasons.
@@ -159,8 +161,8 @@ namespace Beagle {
 
 		[XmlAttribute ("Uri")]
 		public string UriString {
-			get { return UriFu.UriToSerializableString (uri); }
-			set { uri = UriFu.UriStringToUri (value); }
+			get { return UriFu.UriToEscapedString (uri); }
+			set { uri = UriFu.EscapedStringToUri (value); }
 		}
 
 		[XmlIgnore]
@@ -175,14 +177,14 @@ namespace Beagle {
 				if (parent_uri == null)
 					return null;
 
-				return UriFu.UriToSerializableString (parent_uri);
+				return UriFu.UriToEscapedString (parent_uri);
 			}
 
 			set {
 				if (value == null)
 					parent_uri = null;
 				else
-					parent_uri = UriFu.UriStringToUri (value);
+					parent_uri = UriFu.EscapedStringToUri (value);
 			}
 		}
 
@@ -194,8 +196,8 @@ namespace Beagle {
 
 		[XmlAttribute ("ContentUri")]
 		public string ContentUriString {
-			get { return UriFu.UriToSerializableString (ContentUri); }
-			set { contentUri = UriFu.UriStringToUri (value); } 
+			get { return UriFu.UriToEscapedString (ContentUri); }
+			set { contentUri = UriFu.EscapedStringToUri (value); } 
 		}
 
 		[XmlIgnore]
@@ -206,8 +208,8 @@ namespace Beagle {
 		
 		[XmlAttribute ("HotContentUri")]
 		public string HotContentUriString {
-			get { return HotContentUri != null ? UriFu.UriToSerializableString (HotContentUri) : ""; }
-			set { hotContentUri = (value != "") ? new Uri (value) : null; }
+			get { return HotContentUri != null ? UriFu.UriToEscapedString (HotContentUri) : ""; }
+			set { hotContentUri = (value != "") ? UriFu.EscapedStringToUri (value) : null; }
 		}
 
 		[XmlIgnore]
@@ -279,23 +281,28 @@ namespace Beagle {
 		{
 			if (DeleteContent) {
 				if (contentUri != null) {
-					//Logger.Log.Debug ("Cleaning up {0}", contentUri.LocalPath);
+					if (Debug)
+						Logger.Log.Debug ("Cleaning up {0}", contentUri.LocalPath);
+
 					try {
 						File.Delete (contentUri.LocalPath);
-					} catch (Exception ex)
-					{ 
+					} catch { 
 						// It might be gone already, so catch the exception.
 					}
+
 					contentUri = null;
 				}
+
 				if (hotContentUri != null) {
-					//Logger.Log.Debug ("Cleaning up {0}", hotContentUri.LocalPath);
+					if (Debug)
+						Logger.Log.Debug ("Cleaning up {0}", hotContentUri.LocalPath);
+
 					try {
 						File.Delete (hotContentUri.LocalPath);
-					} catch (Exception ex)
-					{
+					} catch {
 						// Ditto
 					}
+
 					hotContentUri = null;
 				}
 			}
@@ -567,17 +574,26 @@ namespace Beagle {
 		public void StoreStream () {
 			if (textReader != null) {
 				ContentUri = TextReaderToTempFileUri (textReader);
-				//Logger.Log.Debug ("Storing text content from {0} in {1}", Uri, ContentUri);
+
+				if (Debug)
+					Logger.Log.Debug ("Storing text content from {0} in {1}", Uri, ContentUri);
+
 				DeleteContent = true;
 			} else if (binary_stream != null) {
 				ContentUri = BinaryStreamToTempFileUri (binary_stream);
-				//Logger.Log.Debug ("Storing binary content from {0} in {1}", Uri, ContentUri);
+
+				if (Debug)
+					Logger.Log.Debug ("Storing binary content from {0} in {1}", Uri, ContentUri);
+
 				DeleteContent = true;
 			}
 
 			if (hotTextReader != null) {
 				HotContentUri = TextReaderToTempFileUri (hotTextReader);
-				//Logger.Log.Debug ("Storing hot content from {0} in {1}", Uri, HotContentUri);
+
+				if (Debug)
+					Logger.Log.Debug ("Storing hot content from {0} in {1}", Uri, HotContentUri);
+
 				DeleteContent = true;
 			}
 		}
