@@ -47,10 +47,6 @@ namespace Beagle.Util {
 		public static DaemonConfig Daemon = null;
 		public static SearchingConfig Searching = null;
 
-//#if ENABLE_WEBSERVICES		
-		public static NetworkingConfig Networking = null;
-		public static WebServicesConfig WebServices = null;
-//#endif 		
 		private static string configs_dir;
 		private static Hashtable mtimes;
 		private static Hashtable subscriptions;
@@ -149,16 +145,6 @@ namespace Beagle.Util {
 		        Searching = (SearchingConfig) temp;
 			NotifySubscribers (Searching);
 
-//#if ENABLE_WEBSERVICES
-			LoadFile (typeof (NetworkingConfig), Networking, out temp, force);
-		    	Networking = (NetworkingConfig) temp;
-			NotifySubscribers (Networking);
-			
-			LoadFile (typeof (WebServicesConfig), WebServices, out temp, force);
-		    	WebServices = (WebServicesConfig) temp;
-			NotifySubscribers (WebServices);
-//#endif
-
 			watching_for_updates = true;
 		}
 
@@ -324,17 +310,6 @@ namespace Beagle.Util {
 				set { show_search_window_binding = value; }
 			}
 
-			private int max_displayed = 5;
-			public int MaxDisplayed {
-				get { return max_displayed; }
-				set {
-					if (value <= 0)
-						max_displayed = 1;
-					else
-						max_displayed = value;
-				}
-			}
-
 			// BeagleSearch window position and dimension
 			// stored as percentage of screen co-ordinates
 			// to deal with change of resolution problem - hints from tberman
@@ -370,6 +345,12 @@ namespace Beagle.Util {
 				set { search_history = value; }
 			}
 
+			private bool beagle_search_auto_search = true;
+			public bool BeagleSearchAutoSearch {
+				get { return beagle_search_auto_search; }
+				set { beagle_search_auto_search = value; }
+			}
+
 		}
 
 		[ConfigSection (Name="daemon")]
@@ -573,7 +554,7 @@ namespace Beagle.Util {
 				ExcludeType type;
 				try {
 					type = (ExcludeType) Enum.Parse (typeof (ExcludeType), args [0], true);
-				} catch (Exception e) {
+				} catch {
 					output = String.Format("Invalid type '{0}'. Valid types: Path, Pattern, MailFolder", args [0]);
 					return false;
 				}
@@ -589,7 +570,7 @@ namespace Beagle.Util {
 				ExcludeType type;
 				try {
 					type = (ExcludeType) Enum.Parse (typeof (ExcludeType), args [0], true);
-				} catch (Exception e) {
+				} catch {
 					output = String.Format("Invalid type '{0}'. Valid types: Path, Pattern, MailFolder", args [0]);
 					return false;
 				}
@@ -608,128 +589,6 @@ namespace Beagle.Util {
 
 		}
 
-//#if ENABLE_WEBSERVICES
-		[ConfigSection (Name="webservices")]
-		public class WebServicesConfig: Section 
-		{
-			private ArrayList publicFolders = new ArrayList ();
-			[XmlArray]
-			[XmlArrayItem(ElementName="PublicFolders", Type=typeof(string))]
-			public ArrayList PublicFolders {
-				get { return publicFolders; }
-				set { publicFolders = value; }
-			}
-
-			private bool allowGlobalAccess = true;
-			public bool AllowGlobalAccess {
-				get { return allowGlobalAccess; }
-				set { allowGlobalAccess = value; }
-			}
-
-			[ConfigOption (Description="List the public folders", IsMutator=false)]
-			internal bool ListPublicFolders(out string output, string [] args)
-			{
-				output = "Current list of public folders:\n";
-
-				foreach (string pf in publicFolders)
-					output += " - " + pf + "\n";
-
-				return true;
-			}
-			
-			[ConfigOption (Description="Check current configuration of global access to Beagle web-services", IsMutator=false)]
-			internal bool CheckGlobalAccess(out string output, string [] args)
-			{
-				if (allowGlobalAccess)
-					output = "Global Access to Beagle WebServices is currently ENABLED.";
-				else
-					output = "Global Access to Beagle WebServices is currently DISABLED.";
-
-				return true;
-			}
-			
-			[ConfigOption (Description="Enable/Disable global access to Beagle web-services")]
-			internal bool SwitchGlobalAccess (out string output, string [] args)
-			{
-				allowGlobalAccess = !allowGlobalAccess;			
-				
-				if (allowGlobalAccess)
-					output = "Global Access to Beagle WebServices now ENABLED.";
-				else
-					output = "Global Access to Beagle WebServices now DISABLED.";
-
-				return true;
-			}
-
-			[ConfigOption (Description="Add public web-service access to a folder", Params=1, ParamsDescription="A path")]
-			internal bool AddPublicFolder (out string output, string [] args)
-			{
-				publicFolders.Add (args [0]);					
-				output = "PublicFolder " + args[0] + " added.";
-				return true;
-			}
-
-			[ConfigOption (Description="Remove public web-service access to a folder", Params=1, ParamsDescription="A path")]
-			internal bool DelPublicFolder (out string output, string [] args)
-			{
-				publicFolders.Remove (args [0]);		
-				output = "PublicFolder " + args[0] + " removed.";
-				return true;
-			}			
-
-		}
-
-		[ConfigSection (Name="networking")]
-		public class NetworkingConfig: Section 
-		{
-			private ArrayList netBeagleNodes = new ArrayList ();
-			
-			[XmlArray]
-			[XmlArrayItem(ElementName="NetBeagleNodes", Type=typeof(string))]
-			public ArrayList NetBeagleNodes {
-				get { return netBeagleNodes; }
-				set { netBeagleNodes = value; }
-			}
-
-			[ConfigOption (Description="List Networked Beagle Daemons to query", IsMutator=false)]
-			internal bool ListBeagleNodes (out string output, string [] args)
-			{
-				output = "Current list of Networked Beagle Daemons to query:\n";
-
-				foreach (string nb in netBeagleNodes)
-					output += " - " + nb + "\n";
-				
-				return true;
-			}
-
-			[ConfigOption (Description="Add a Networked Beagle Daemon to query", Params=1, ParamsDescription="HostName:PortNo")]
-			internal bool AddBeagleNode (out string output, string [] args)
-			{
-				string node = args[0];
-				
-				if (((string[])node.Split(':')).Length < 2)
-					node = args [0].Trim() + ":8888";
-							
-				netBeagleNodes.Add(node);			
-				output = "Networked Beagle Daemon \"" + node +"\" added.";
-				return true;
-			}
-
-			[ConfigOption (Description="Remove a configured Networked Beagle Daemon", Params=1, ParamsDescription="HostName:PortNo")]
-			internal bool DelBeagleNode (out string output, string [] args)
-			{
-				string node = args[0];
-				
-				if (((string[])node.Split(':')).Length < 2)
-					node = args [0].Trim() + ":8888";
-							
-				netBeagleNodes.Remove(node);					
-				output = "Networked Beagle Daemon \"" + node +"\" removed.";
-				return true;
-			}
-		}
-//#endif
-
 		public class Section {
 			[XmlIgnore]
 			public bool SaveNeeded = false;
