@@ -131,48 +131,6 @@ namespace Beagle.Util {
 
 		public const string MimeType = "beagle/x-gaim-log";
 
-		private static string StripTags (string line, StringBuilder builder)
-		{
-			int first = line.IndexOf ('<');
-			if (first == -1)
-				return line;
-			
-			builder.Length = 0;
-
-			int i = 0;
-			while (i < line.Length) {
-				
-				int j;
-				if (first == -1) {
-					j = line.IndexOf ('<', i);
-				} else {
-					j = first;
-					first = -1;
-				}
-				
-				int k = -1;
-				if (j != -1) {
-					k = line.IndexOf ('>', j);
-					
-					// If a "<" is unmatched, preserve it, and the
-					// rest of the line
-					if (k == -1)
-						j = -1;
-				}
-				
-				if (j == -1) {
-					builder.Append (line, i, line.Length - i);
-					break;
-				}
-				
-				builder.Append (line, i, j-i);
-				
-				i = k+1;
-			}
-			
-			return builder.ToString ();
-		}
-
 		///////////////////////////////////////
 
 		public GaimLog (FileInfo file, TextReader reader) : base ("gaim", file, reader)
@@ -212,7 +170,7 @@ namespace Beagle.Util {
 				} else {
 					throw new FormatException ();
 				}
-			} catch (Exception) {
+			} catch {
 				Logger.Log.Warn ("Could not parse date/time from filename '{0}'", file.Name);
 				StartTime = DateTime.Now;
 			}
@@ -268,14 +226,25 @@ namespace Beagle.Util {
 			}
 
 			line = line.Substring (j+2);
-						
+
 			// Extract the alias
-			// FIXME: This will break if there is a ':' in the nickname
-			int i = line.IndexOf (':');
-			if (i == -1)
-				return;
-			string alias = line.Substring (0, i);
-			string text = line.Substring (i+2);
+			string alias, text;
+			int i;
+
+			if (line.StartsWith ("***")) {
+				i = line.IndexOf (' ');
+
+				alias = line.Substring (3, i - 3);
+				text = line.Substring (i + 1);
+			} else {
+				// FIXME: This will break if there is a ':' in the nickname
+				i = line.IndexOf (':');
+				if (i == -1 || line.Length < i + 2)
+					return;
+
+				alias = line.Substring (0, i);
+				text = line.Substring (i + 2);
+			}
 
 			AddUtterance (timestamp, alias, text);
 
@@ -300,9 +269,14 @@ namespace Beagle.Util {
 				
 			while ((line = TextReader.ReadLine ()) != null) {
 				if (isHtml)
-					line = StripTags (line, builder);
+					line = StringFu.StripTags (line, builder);
 			
-				ProcessLine (line);
+				try {
+					ProcessLine (line);
+				} catch (Exception e) {
+					Logger.Log.Warn ("Could not parse line in '{0}'", File.FullName);
+					Logger.Log.Warn (e);
+				}
 			}
 		}
 	}
@@ -321,14 +295,24 @@ namespace Beagle.Util {
 			// FIXME: Artificially split logs into conversations depending on the
 			// amount of time elapsed betweet messages?
 			
-			// Figure out the protocol from the parent.parent foldername
-			Protocol = file.Directory.Parent.Name.Substring (0, file.Directory.Parent.Name.Length - 8).ToLower ().ToLower ();
+			// Figure out the protocol from the parent.parent or parent foldername
+			if (file.Directory.Parent.Name.EndsWith ("Protocol"))
+				Protocol = file.Directory.Parent.Name.Substring (0, file.Directory.Parent.Name.Length - 8).ToLower ();
+			else if (file.Directory.Name.EndsWith ("Protocol"))
+				Protocol = file.Directory.Name.Substring (0, file.Directory.Name.Length - 8).ToLower ();
+			else
+				Protocol = file.Directory.Name;
 			Identity = file.Directory.Name;
 
 			// FIXME: This is not safe for all kinds of file/screennames
 			string filename = Path.GetFileNameWithoutExtension (file.Name);
-			SpeakingTo = filename.Substring (0, filename.LastIndexOf ('.'));
-
+			if (filename.LastIndexOf ('.') > 0)
+				SpeakingTo = filename.Substring (0, filename.LastIndexOf ('.'));
+			else if (filename.LastIndexOf ('_') > 0)
+				SpeakingTo = filename.Substring (0, filename.LastIndexOf ('_'));
+			else
+				SpeakingTo = filename;
+			Logger.Log.Debug ("Speakingto for " + file.Name + " is " + SpeakingTo + ", protocol is " + Protocol);
 			Load ();
 		}
 		
@@ -369,6 +353,12 @@ namespace Beagle.Util {
 									  base_date.Year,
 									  base_date.Month,
 									  reader.GetAttribute ("time"));
+					int time_separator_count = 0;
+					foreach (int the_char in timestamp)
+						if (the_char == ':')
+							time_separator_count++;
+					if (time_separator_count < 2)
+						timestamp = timestamp + ":00";
 
 					DateTime msg_date = DateTime.MinValue;
 
@@ -376,7 +366,7 @@ namespace Beagle.Util {
 						msg_date = DateTime.ParseExact (timestamp,
 										date_format,
 										null);
-					} catch (Exception ex) {
+					} catch {
 						Logger.Log.Error ("Couldn't parse Kopete timestamp: {0}", timestamp);
 						break;
 					}
