@@ -55,6 +55,11 @@ namespace Beagle.Util {
 		static private TextWriter exception_writer;
 		static private TextWriter foreground_echo_writer;
 
+		static public LogLevel Level {
+			get { return cutoff_level; }
+			set { cutoff_level = value; }
+		}
+
 		static public void Initialize (string   log_directory,
 					       string   program_identifier,
 					       LogLevel cutoff_level,
@@ -68,7 +73,11 @@ namespace Beagle.Util {
 			PruneOldLogs ();
 
 			log_name_prefix = String.Format ("{0:yyyy-MM-dd-HH-mm-ss}-", DateTime.Now);
-			program_identifier_truncated = program_identifier.Substring (0, 6);
+
+			if (program_identifier.Length > 6)
+				program_identifier_truncated = program_identifier.Substring (0, 6);
+			else
+				program_identifier_truncated = program_identifier;
 
 			log_writer = NewLogWriter (program_identifier);
 			exception_writer = NewDelayedLogWriter (program_identifier + "Exceptions");
@@ -136,7 +145,7 @@ namespace Beagle.Util {
 					log_date = DateTime.ParseExact (date, "yyyy-MM-dd-HH-mm-ss", null);
 					if (log_date < magic_date)
 						file.Delete ();
-				} catch (Exception e) {	}
+				} catch { }
 			}				
 		}
 
