@@ -41,11 +41,13 @@ namespace Beagle.Util {
 
 		public const string UnindexedNamespace = "_unindexed:";
 
-		private const String timeFormat = "yyyyMMddHHmmss";
+		private const String TimeFormat = "yyyyMMddHHmmss";
+		// FIXME: Fix all the UTC and timezone hack when switching to gmcs
+		private const String LocalTimeFormat = "yyyyMMddHHmmsszz";
 
 		static public string DateTimeToString (DateTime dt)
 		{
-			return dt.ToString (timeFormat);
+			return dt.ToString (TimeFormat);
 		}
 
 		static public string DateTimeToYearMonthString (DateTime dt)
@@ -63,7 +65,14 @@ namespace Beagle.Util {
 			if (str == null || str == "")
 				return new DateTime ();
 
-			return DateTime.ParseExact (str, timeFormat, CultureInfo.CurrentCulture);
+			str = string.Concat (str, "+00");
+			// Uncomment next 3 lines to see what how 20061107173446 (which is stored in UTC)
+			// used to be parsed as 2006-11-07T17:34:46.0000000-05:00
+			//DateTime dt = DateTime.ParseExact (str, LocalTimeFormat, CultureInfo.InvariantCulture);
+			//Console.WriteLine ("Parsed {0} as {1},{2}", str, dt, dt.ToString("yyyy-MM-ddTHH:mm:ss.fffffffzzz", CultureInfo.InvariantCulture));
+			//return dt;
+			// If no timezone is present, parse_exact uses local time zone
+			return DateTime.ParseExact (str, LocalTimeFormat, CultureInfo.InvariantCulture);
                 }
 
 		static public string DateTimeToFuzzy (DateTime dt)
@@ -302,15 +311,22 @@ namespace Beagle.Util {
 		static public string HexEscape (string str)
 		{
 			StringBuilder builder = new StringBuilder ();
-			int i;
 
-			while ((i = str.IndexOfAny (CharsToQuote)) != -1) {
-				if (i > 0)
-					builder.Append (str.Substring (0, i));
-				builder.Append (Uri.HexEscape (str [i]));
-				str = str.Substring (i+1);
+			foreach (char c in str) {
+
+				if (Array.IndexOf (CharsToQuote, c) != -1)
+					builder.Append (Uri.HexEscape (c));
+				else if (c < 128)
+					builder.Append (c);
+				else {
+					byte[] utf8_bytes;
+
+					utf8_bytes = Encoding.UTF8.GetBytes (new char [] { c });
+
+					foreach (byte b in utf8_bytes)
+						builder.AppendFormat ("%{0:X}", b);
+				}
 			}
-			builder.Append (str);
 
 			return builder.ToString ();
 		}
@@ -318,21 +334,23 @@ namespace Beagle.Util {
 		// Translate all %xx codes into real characters
 		static public string HexUnescape (string str)
 		{
-			int i = 0, pos = 0;
-			while ((i = str.IndexOf ('%', pos)) != -1) {
-				pos = i;
-				char unescaped = Uri.HexUnescape (str, ref pos);
-				str = str.Remove (i, 3);
-				str = str.Insert (i, new String(unescaped, 1));
-				pos -= 2;
-			}
-			return str;
-		}
+			ArrayList bytes = new ArrayList ();
+                        byte[] sub_bytes;
+                        int i, pos = 0;
 
-		static public string PathToQuotedFileUri (string path)
-		{
-			path = Path.GetFullPath (path);
-			return Uri.UriSchemeFile + Uri.SchemeDelimiter + HexEscape (path);
+                        while ((i = str.IndexOf ('%', pos)) != -1) {
+                                sub_bytes = Encoding.UTF8.GetBytes (str.Substring (pos, i - pos));
+                                bytes.AddRange (sub_bytes);
+				
+				pos = i;
+                                char unescaped = Uri.HexUnescape (str, ref pos);
+				bytes.Add ((byte) unescaped);
+                        }
+
+                        sub_bytes = Encoding.UTF8.GetBytes (str.Substring (pos, str.Length - pos));
+                        bytes.AddRange (sub_bytes);
+
+                        return Encoding.UTF8.GetString ((byte[]) bytes.ToArray (typeof (byte)));
 		}
 
 		// These strings should never be exposed to the user.
