@@ -78,14 +78,12 @@ namespace Beagle.Daemon {
 		private static void LogMemoryUsage ()
 		{
 			while (! Shutdown.ShutdownRequested) {
-				int vm_size = SystemInformation.VmSize;
 				int vm_rss = SystemInformation.VmRss;
 
-				Logger.Log.Debug ("Memory usage: VmSize={0:.0} MB, VmRSS={1:.0} MB,  GC.GetTotalMemory={2}",
-						  vm_size/1024.0, vm_rss/1024.0, GC.GetTotalMemory (false));
+				SystemInformation.LogMemoryUsage ();
 
-				if (vm_size > 300 * 1024) {
-					Logger.Log.Debug ("VmSize too large --- shutting down");
+				if (vm_rss > 300 * 1024) {
+					Logger.Log.Debug ("VmRss too large --- shutting down");
 					Shutdown.BeginShutdown ();
 				}
 
@@ -147,12 +145,11 @@ namespace Beagle.Daemon {
 			}
 			
 			// Set up out-of-process indexing
-			if (Environment.GetEnvironmentVariable ("BEAGLE_ENABLE_IN_PROCESS_INDEXING") == null)
-				LuceneQueryable.IndexerHook = new LuceneQueryable.IndexerCreator (RemoteIndexer.NewRemoteIndexer);
+			LuceneQueryable.IndexerHook = new LuceneQueryable.IndexerCreator (RemoteIndexer.NewRemoteIndexer);
 
-			// Initialize synchronization to keep the indexes local if PathFinder.HomeDir
+			// Initialize synchronization to keep the indexes local if PathFinder.StorageDir
 			// is on a non-block device, or if BEAGLE_SYNCHRONIZE_LOCALLY is set
-			if ((! SystemInformation.IsPathOnBlockDevice (PathFinder.HomeDir) && Conf.Daemon.IndexSynchronization) ||
+			if ((! SystemInformation.IsPathOnBlockDevice (PathFinder.StorageDir) && Conf.Daemon.IndexSynchronization) ||
 			    Environment.GetEnvironmentVariable ("BEAGLE_SYNCHRONIZE_LOCALLY") != null)
 				IndexSynchronization.Initialize ();
 
@@ -191,6 +188,8 @@ namespace Beagle.Daemon {
 
 			Logger.Log.Debug ("Daemon initialization finished after {0}", stopwatch);
 
+			SystemInformation.LogMemoryUsage (); 
+
 			if (arg_indexing_test_mode) {
 				Thread.Sleep (1000); // Ugly paranoia: wait a second for the backends to settle.
 				Logger.Log.Debug ("Running in indexing test mode");
@@ -245,8 +244,10 @@ namespace Beagle.Daemon {
 					break;
 
 				case "--heap-buddy":
+				case "--heap-shot":
 				case "--mdb":
-					// Silently ignore the --heap-buddy argument: it gets handled
+				case "--mono-debug":
+					// Silently ignore these arguments: they get handled
 					// in the wrapper script.
 					break;
 
@@ -449,6 +450,10 @@ namespace Beagle.Daemon {
 			Logger.Log.Debug ("Starting main loop");
 			main_loop.Run ();
 
+			// We're out of the main loop now, join all the
+			// running threads so we can exit cleanly.
+			ExceptionHandlingThread.JoinAllThreads ();
+
 			// If we placed our sockets in a temp directory, try to clean it up
 			// Note: this may fail because the helper is still running
 			if (PathFinder.GetRemoteStorageDir (false) != PathFinder.StorageDir) {
@@ -457,16 +462,11 @@ namespace Beagle.Daemon {
 				} catch (IOException) { }
 			}
 
-			Logger.Log.Debug ("Leaving BeagleDaemon.Main");
-
-			if (arg_debug) {
-				Thread.Sleep (500);
-				ExceptionHandlingThread.SpewLiveThreads ();
-			}
+			Log.Info ("Beagle daemon process shut down cleanly.");
 		}
 
 		/////////////////////////////////////////////////////////////////////////////
-
+		
 		private static bool prev_on_battery = false;
 
 		private static bool CheckBatteryStatus ()
