@@ -60,7 +60,7 @@ namespace Beagle.IndexHelper {
 			}
 		}
 
-		[DllImport("libgobject-2.0.so")]
+		[DllImport("libgobject-2.0.so.0")]
 		static extern void g_type_init ();
 
 		private static void DoMain (string [] args)
@@ -111,14 +111,22 @@ namespace Beagle.IndexHelper {
 				server.Start ();
 				server_has_been_started = true;
 			} catch (InvalidOperationException ex) {
-				Logger.Log.Error (ex, "Couldn't start server:");
+				Logger.Log.Error (ex, "Couldn't start server.  Exiting immediately.");
 			}
 
 			if (server_has_been_started) {
 				// Set the IO priority to idle so we don't slow down the system
 				if (Environment.GetEnvironmentVariable ("BEAGLE_EXERCISE_THE_DOG") == null) {
-					if (! IoPriority.SetIdle ())
-						IoPriority.SetIoPriority (7);
+					IoPriority.ReduceIoPriority ();
+
+					int prio = Mono.Unix.Native.Syscall.nice (15);
+
+					if (prio < 0)
+						Log.Warn ("Unable to renice helper to +15");
+					else if (prio == 15)
+						Log.Debug ("Reniced helper to +15");
+					else
+						Log.Debug ("Helper was already niced to {0}, not renicing to +15", prio);
 				}
 				
 				// Start the monitor thread, which keeps an eye on memory usage and idle time.
@@ -128,16 +136,20 @@ namespace Beagle.IndexHelper {
 				// if it terminates.
 				ExceptionHandlingThread.Start (new ThreadStart (DaemonMonitorWorker));
 
-				//Application.Run ();
+				// Start the main loop
 				main_loop.Run ();
 
-				// If we palced our sockets in a temp directory, try to clean it up
+				ExceptionHandlingThread.JoinAllThreads ();
+
+				// If we placed our sockets in a temp directory, try to clean it up
 				// Note: this may fail because the daemon is still running
 				if (PathFinder.GetRemoteStorageDir (false) != PathFinder.StorageDir) {
 					try {
 						Directory.Delete (PathFinder.GetRemoteStorageDir (false));
 					} catch (IOException) { }
 				}
+
+				Log.Info ("Index helper process shut down cleanly.");
 			}
 		}
 
